@@ -3,6 +3,7 @@ import os
 import pathlib
 import logging
 import traceback
+import functools
 from .uwException import * 
 
 class cmnConfig:
@@ -32,6 +33,21 @@ class cmnConfig:
         self.config_ini = None
         """ iniファイル読込内容 """
 
+    def getConfigFileName(self):
+        
+        """ 
+        設定ファイル名を取得する
+        
+        Returns
+        -------
+            設定ファイル名
+        
+        Notes
+        -----
+            設定ファイル名を変更したい場合はcmnConfigを継承して当メソッドをオーバーライドする
+        """
+        return 'config.ini'
+    
     def getConfig(self, scriptPath: str, configFileDirName: str = ''):
 
         """ 
@@ -53,7 +69,7 @@ class cmnConfig:
 
         # iniファイルパス取得
         iniDirPath = pathlib.Path(os.path.abspath(os.path.dirname(scriptPath)))
-        iniFilePath = os.path.join(iniDirPath, configFileDirName, 'config.ini')
+        iniFilePath = os.path.join(iniDirPath, configFileDirName, self.getConfigFileName())
 
         # iniファイル存在確認
         if (not os.path.exists(iniFilePath)): 
@@ -101,14 +117,59 @@ class cmnConfig:
             iniファイルキー名
         dataType : type
             インスタンス変数のデータ型
+        
+        Notes
+        -----
+        
+            @insVariableName
+            ----------------
+                インスタンス変数名をネストする場合は"."コロンで区切る 
+                例:self.STRUCT.Test1の場合 ⇒ insVariableNameに"STRUCT.Test1"を指定する 
+        
         """
 
         if config_ini[section].get(key) != None:
             
             if dataType is str:
-                setattr(self, insVariableName, config_ini[section][key])
+                self.rsetattr(self, insVariableName, config_ini[section][key])
             elif dataType is int:
-                setattr(self, insVariableName, int(config_ini[section][key]))
+                self.rsetattr(self, insVariableName, int(config_ini[section][key]))
             elif dataType is float:
-                setattr(self, insVariableName, float(config_ini[section][key]))
+                self.rsetattr(self, insVariableName, float(config_ini[section][key]))
 
+    def rsetattr(self, obj, attr, val):
+        
+        """ 
+        インスタンス変数の値を書き換える(ネスト用setattr)
+
+        Parameters
+        ----------
+        obj : LibHanger.cmnConfig
+            cmnConfigインスタンス
+        attr : str
+            インスタンス変数名
+        val : object
+            置き換える値
+        """
+        
+        pre, _, post = attr.rpartition('.')
+        return setattr(self.rgetattr(obj, pre) if pre else obj, post, val)
+
+    def rgetattr(self, obj, attr, *args):
+        
+        """ 
+        インスタンス変数を参照する(ネスト用getattr)
+
+        Parameters
+        ----------
+        obj : LibHanger.cmnConfig
+            cmnConfigインスタンス
+        attr : str
+            インスタンス変数名
+        *args : object
+            Unknown
+        """
+        
+        def _getattr(obj, attr):
+            return getattr(obj, attr, *args)
+        return functools.reduce(_getattr, [obj] + attr.split('.'))
\ No newline at end of file
